@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-template
 version: 2.1.5
-id: persistent-template-2.1.5-5a5a189d5669eb41fa0516076c32ca83
-key: persi_3OFXwuDnQRIF9YiSS4BHWE
+id: persistent-template-2.1.5-8e80a31cb67cc3ef9d0a8d75e0beb774
+key: persi_5SC4flOyqRmDO6oU34Nasq
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -20,7 +20,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.5
-hs-libraries: HSpersistent-template-2.1.5-3OFXwuDnQRIF9YiSS4BHWE
+hs-libraries: HSpersistent-template-2.1.5-5SC4flOyqRmDO6oU34Nasq
 depends:
     aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
     aeson-compat-0.3.0.0-a20a161a51c55c8ab6017f045ab6c3e9
@@ -30,9 +30,9 @@ depends:
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.17-d3b65fae3959e41c01434c1c220af3fd
+    monad-logger-0.3.18-2bfbe07c1c1cdc537fa81b345cec7330
     path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
-    persistent-2.2.4-6358b6402a63bdc879cbf54a9eb5e6c6
+    persistent-2.2.4-3efd0b27ba9bd4f18bae3621104638b2
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
